<?php

namespace Matomo_Tracker\Inc\Core;
use Matomo_Tracker as NS;
use Matomo_Tracker\Inc\Admin as Admin;
use Matomo_Tracker\Inc\Frontend as Frontend;

/**
 * The core plugin class.
 * Defines internationalization, admin-specific hooks, and public-facing site hooks.
 *
 * @link       https://www.niroma.net
 * @since      1.0.0
 *
 * @author     Niroma
 */
class Init {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @var      Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_base_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_basename;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * The text domain of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $plugin_text_domain;
	
	protected $plugin_name_dir;
	protected $plugin_name_url;

	/**
	 * Initialize and define the core functionality of the plugin.
	 */
	public function __construct() {

		//add_action( 'plugins_loaded', array( $this, 'check_if_user_logged_in' ) );

		$this->plugin_name = NS\PLUGIN_NAME;
		$this->version = NS\PLUGIN_VERSION;
		$this->plugin_basename = NS\PLUGIN_BASENAME;
		$this->plugin_text_domain = NS\PLUGIN_TEXT_DOMAIN;
		
		$this->plugin_name_dir = NS\PLUGIN_NAME_DIR;
		$this->plugin_name_url = NS\PLUGIN_NAME_URL;

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();
		
	}

	/**
	 * Loads the following required dependencies for this plugin.
	 *
	 * - Loader - Orchestrates the hooks of the plugin.
	 * - Internationalization_I18n - Defines internationalization functionality.
	 * - Admin - Defines all hooks for the admin area.
	 * - Frontend - Defines all hooks for the public side of the site.
	 *
	 * @access    private
	 */
	private function load_dependencies() {
		$this->loader = new Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Internationalization_I18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @access    private
	 */
	private function set_locale() {

		$plugin_i18n = new Internationalization_I18n( $this->plugin_text_domain );

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @access    private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Admin\Admin( $this->get_plugin_name(), $this->get_version(), $this->get_plugin_text_domain(), $this->get_plugin_name_dir(), $this->get_plugin_name_url() );
		
		//$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );

		/*
		 * Additional Hooks go here
		 *
		 * e.g.
		 *
		 * //admin menu pages
		 * $this->loader->add_action('admin_menu', $plugin_admin, 'add_plugin_admin_menu');
		 *
		 *  //plugin action links
		 * $this->loader->add_filter( 'plugin_action_links_' . $this->plugin_basename, $plugin_admin, 'add_additional_action_link' );
		 *
		 */
		$this->loader->add_action( 'admin_menu', $plugin_admin, 'add_plugin_admin_menu' );
		$this->loader->add_action( 'admin_post_matomo_tracker_form_response', $plugin_admin, 'check_for_event_submissions');
		$this->loader->add_action( 'admin_notices', $plugin_admin, 'print_plugin_admin_notices');
		/*$this->loader->add_action( 'upgrader_process_complete', $plugin_admin, 'check_for_update');*/

	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @access    private
	 */
	private function define_public_hooks() {

		$plugin_public = new Frontend\Frontend( $this->get_plugin_name(), $this->get_version(), $this->get_plugin_text_domain(), $this->get_plugin_name_dir() );

		//$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		//$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );
		
		/*$this->loader->add_action( 'plugins_loaded', $plugin_public, 'check_if_user_logged_in' );*/
		$display = true;
		if ( !empty(get_option( $this->plugin_name.'-users-auth' )) && get_option( $this->plugin_name.'-users-auth' ) == $this->check_if_user_logged_in() ) 
			$display = false;
		
		
		if ($display) {
			if ( !empty(get_option( $this->plugin_name.'-tracking-mode' )) && get_option( $this->plugin_name.'-tracking-mode') == 'php' ) {
				$this->loader->add_action('wp_head', $plugin_public, 'add_php_tracking');
			} else {
				if ( get_option( $this->plugin_name.'-tracking-mode') == 'jsi' ) {
					$this->loader->add_action( 'wp_footer', $plugin_public, 'add_tracking_code_footer' );
				} else {
					$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_tracking_script');
									
					if ( empty(get_option( $this->plugin_name.'-javascript-disallow-robot' )) || get_option( $this->plugin_name.'-javascript-disallow-robot') == 'y' ) {
						$this->loader->add_filter( 'robots_txt', $plugin_public, 'disallow_javascript_tracking', 10, 2 );
					}
				}
			}
		} else {
			$this->loader->add_action( 'wp_footer', $plugin_public, 'add_note_footer');
		}
	}
	
	public function check_if_user_logged_in() {
		if(!function_exists('wp_get_current_user')) {
			include(ABSPATH . "wp-includes/pluggable.php"); 
		}
		if( current_user_can('administrator') && get_option( $this->plugin_name.'-users-auth' ) == 'admin' ) return 'admin';
		if ( is_user_logged_in() ) return 'loggedin';
		return '';
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @return    Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

	/**
	 * Retrieve the text domain of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The text domain of the plugin.
	 */
	public function get_plugin_text_domain() {
		return $this->plugin_text_domain;
	}
	
	public function get_plugin_name_dir() {
		return $this->plugin_name_dir;
	}
	
	public function get_plugin_name_url() {
		return $this->plugin_name_url;
	}
	

}
